@@ -2,10 +2,11 @@ import gzip
 import pickle
 from io import DEFAULT_BUFFER_SIZE
 from json import dump, load
-from os import makedirs, remove, rmdir, PathLike
+from os import makedirs, remove, rmdir
 from os.path import exists, dirname, join, basename, isdir
 from shutil import copyfile
-from typing import Union, Optional, TextIO, Any
+from sys import stdout
+from typing import Union, Optional, TextIO, Any, List
 
 from typing.io import IO
 
@@ -233,3 +234,25 @@ def touch(filename: str) -> None:
     :param filename: The path to the file to create.
     """
     open(filename, 'w').close()
+
+
+def cat(filename: str, output: TextIO = stdout) -> None:
+    """ Print a file content.
+
+    :param filename: The path to the file. If the file name ends with ".gz", this function decompressed it to print.
+    :param output: The stream to print. By default, the standard output.
+    """
+    with open_file(filename, 'rt') as file:
+        for line in file:
+            print(line, end='', file=output)
+
+
+def read_file(filename: str, line_break: bool = True) -> List[str]:
+    """ Read a file (compressed with gzip or not) and return in a list its content, each line in a list element.
+
+    :param filename: The path to the file. If the file name ends with ".gz", this function decompressed it first.
+    :param line_break: If True, the newline character is conserved, otherwise is removed.
+    :return: An array with the contents of the file.
+    """
+    with open_file(filename, 'rt') as file:
+        return [line[:-1] if not line_break and line[-1] == '\n' else line for line in file]
